type FiveRecordFieldsValuesType = {
    fields: Array<string>;
    values: Array<any>;
}

export class FiveRecord {
    key: string;
    versionKey: string;
    dateStart: string;
    data: any;

    constructor(key: string, versionKey: string, data: any, dateStart?: string) {
        this.key = key;
        this.versionKey = versionKey;
        this.data = data;
        this.dateStart = dateStart ? dateStart : '';;
    }

    dup(): FiveRecord {
        const data = JSON.parse(JSON.stringify(this.data));
        const record = new FiveRecord(this.key, this.versionKey, data);
        return record;
    }

    isNewRecord(): boolean {
        if (this.data === null) {
            return true;
        }
        return false;
    }

    // we specify any as it now returns a special Keys Object, we need to make this part of the external api
    getKey(): any {
        return this.key;
    }

    getVersionKey(): string {
        return this.versionKey;
    }

    setKey(key: string) {
        this.key = key;
    }

    setVersionKey(versionKey: string) {
        this.versionKey = versionKey;
    }

    setData(data: any): void {
        this.data = data;
    }

    getValue(fieldName: string): any {
        const partialMatch = fieldName.indexOf('.') === -1;
        if (!partialMatch) {
            return this.data[fieldName];
        }

        const keys = Object.keys(this.data);
        for (let i = 0; i < keys.length; i++) {
            const key = keys[i];
            if (key.indexOf(fieldName) != -1) {
                return this.data[key];
            }
        }

        return null;
    }

    getFieldNameValues() : FiveRecordFieldsValuesType {
        const fields = new Array<string>();
        const values = new Array<any>();
        const keys = Object.keys(this.data);
        keys.forEach((key: any) => {
            fields.push(key);
            values.push(this.data[key]);
        })

        const fieldsAndValues: FiveRecordFieldsValuesType = {
            fields: fields,
            values: values,
        };

        return fieldsAndValues;
    }
}

export class QuestionDialogParameters {
    question: string;
    onPositiveText: string;
    onNegativeText: string;
    onPositiveAction: (() => void) | null;
    onNegativeAction: (() => void) | null;

    constructor(question: string) {
        this.question = question;
        this.onPositiveText = 'Yes';
        this.onNegativeText = 'No';
        this.onPositiveAction = null;
        this.onNegativeAction = null;
    }
}
